@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package IO::TieCombine;
 {
-  $IO::TieCombine::VERSION = '1.002';
+  $IO::TieCombine::VERSION = '1.003';
 }
 # ABSTRACT: produce tied (and other) separate but combined variables
 
@@ -122,6 +122,7 @@ sub callback {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -130,7 +131,7 @@ IO::TieCombine - produce tied (and other) separate but combined variables
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 SYNOPSIS
 
@@ -167,6 +168,13 @@ tied filehandle using C<say> B<will not have the expected newline>.  5.10.1 or
 later is needed.  Since 5.10.0 is broken in so many other ways, you should
 really upgrade anyway.
 
+B<ACHTUNG!!>  Because of a different problem with Perls 5.10.1 - 5.16.3, if you
+send output to a tied filehandle using C<say>, and C<$\> is undefined (which is
+the default), B<< C<$\> will not be restored to C<undef> after the C<say> >>!
+This means that once you've used C<say> to print to I<any> tied filehandle, you
+have corrupted the global state of your program.  Either start your program by
+setting C<$\> to an empty string, which should be safe, or upgrade to 5.18.0.
+
 =head1 METHODS
 
 =head2 new
@@ -214,10 +222,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
